# -*- coding: utf-8 -*-
"""
Created on Fri Apr  1 22:44:28 2022

Description: Script used for computing drifts and envelopes from the processed data

Input files: Processed data (in .csv)
Output files: 
    1. Envelope for each loading direction (in .csv)
    2. Drifts for each loading direction (in .csv)
    3. Several plots (if needed)

@author: Jakov Oreb
Date of last revision: 20.05.2025.

"""

#%%
# Clean all variables
globals().clear()

import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import os
import math
#%% Close all images
plt.close('all')

#%% INPUT DATA

# Define the folder location with the DIC and CATMAN data:
data_folder_path = '../01_data'
data_file = 'SCW_A_clean_data.csv'

# Combine them into a full path
full_path = os.path.join(data_folder_path, data_file)

# Read the CSV
data = pd.read_csv(full_path, header=None)  # or header=0 if your file has headers

wall_name = 'SCW_A'

output_drifts_Plaster = wall_name +'_drifts_Plaster.csv'
#output_drifts_stone =  wall_name + '_drifts_stone.csv'

output_envelope_Plaster =  wall_name + '_envelope_Plaster'
#output_envelope_stone =  wall_name + '_envelope_stone'

# NUMBER OF SIDES TO CONSIDER (2 For both wall sides, 1 for only one)
nsides = 1


# VARIABLES TO PLOT
uDIC_Plaster_column = 'DIC_Plate_Plaster_side_mean_plate_[mm]'

#uDIC_Stone_column = 'DIC_Plate_Stone_side_mean_plate_[mm]'

uLVDT_name = 'LVDT5_Plaster_East_[mm]'
hforce_name = 'Horizontal_force_[kN]'

#DRIFT
wall_height = 1400 # [mm]
area =1400*400
drift_stone = False # if False, the Plaster side will be considered for computing the drift

# SPECIFICATIONS ON PLOTTED DATA

#AXIS LIMITS

# drifts
drifts_lim = [-2,2]
# drifts
displacement_lim = [-28,28]
# stress [MPa]
stress_lim = [-1.50,1.50]
#force (kN)
force_lim = [-800,800]


# Remove first reading from all the data
remove_initial_reading = False   # Removes initial Reading before LS1

# Save image
save_image = False; image_name = 'SCW_A'

#PLOTS
title = 'SCW_A 1.4m'
x_title = 'Displacement [mm]'          # Title of the x-axis
y_title = 'Force [kN]'  # Title of the y-axis
plot_width = 1.0 # Width of lines (can be changed below as well)

# Fonts
# font = {'family': 'Arial',
#         'color':  'black',
#         'weight': 'normal',
#         'size': 13,
#         }

plt.rcParams['font.sans-serif'] = "Arial"
plt.rcParams['font.family'] = "sans-serif"


#%% FUNCTIONS

# Envelope of x-y graph computed as the y-value for first occurence of an x-value
def compute_envelope(x_inp,y_inp):
    max_dis=0
    x_env = np.array([])
    y_env = np.array([])
    if x_inp[0] == 0:
        x_env = np.append(x_env,x_inp[0])
        y_env = np.append(y_env,y_inp[0])        
    for i in range(1,len(x_inp)):
        dx = x_inp[i]-x_inp[i-1]
        if dx > 0:
            if x_inp [i]>= max_dis:
                max_dis = x_inp[i]
                x_env = np.append(x_env,x_inp[i])
                y_env = np.append(y_env,y_inp[i])
    return x_env,y_env

def compute_drift(x_inp,y_inp,factor,idx_peak, wall_height):
    absolute_max = max(abs(y_inp))
    for i in range(idx_peak,len(x_inp)): # search only after peak
        if abs(y_inp[i]) > factor*absolute_max:
            if i+1 < len(x_inp):
                index =i+1 
            else:
                index = i 
                
        drift = x_inp[index]/wall_height*100
        hforce_at_drift = y_inp[index]
    if y_inp[-1] < 0:
        direction = 'negative'
    else:
        direction = 'positive'
    
    print('Drift at ', math.ceil((1-factor)*100), ' % drop - ', direction, ' :', "%0.2f" % drift, ' - FORCE [kN]: ', hforce_at_drift)
    
    return drift,hforce_at_drift


#%% PROCEDURE

path_file = os.path.join(data_folder_path,data_file)
fig_num =0

df =pd.read_csv(path_file,index_col=False)
df.columns = df.columns.str.replace(" ", "_")

#%% Retrieve displacements from DIC
uDIC_Plaster = df[uDIC_Plaster_column] #average displacement on plate at Plaster side

#uDIC_Stone = df[uDIC_Stone_column] #average displacement on plate at stone side

#Retrieve Horizontal Force
uLVDT = pd.DataFrame(df, columns= [uLVDT_name])
uLVDT = uLVDT.to_numpy().flatten()
hforce = pd.DataFrame(df, columns= [hforce_name]) # Horizontal force
uDIC_Plaster = uDIC_Plaster.to_numpy().flatten()
#uDIC_Stone = uDIC_Stone.to_numpy().flatten()
hforce = hforce.to_numpy().flatten()

if remove_initial_reading == True:
    uDIC_Plaster -= uDIC_Plaster[0]
#    uDIC_Stone -= uDIC_Stone[0]
    uLVDT -= uLVDT[0]
    hforce -= hforce[0]

# Compute envolopes and drift for nsides
for j in range(nsides):
    if j == 0:
        df_displacements = df[uDIC_Plaster_column].copy()
        print('***************************************************************')
        print('Plaster SIDE')
        print(' ')
        envelope_output_name = output_envelope_Plaster
        plot_title = title + " Plaster side"
#    else:
#        df_displacements = df[uDIC_Stone_column].copy() 
#        print('***************************************************************')
#        print('STONE SIDE')
#        print(' ')
#        envelope_output_name = output_envelope_stone
#        plot_title = title + " Stone side"

    #%% Separate Loading directions by looking at the sign of the displacements
    
    uDIC_positive = df_displacements.loc[df_displacements>=0]
    uDIC_positive = uDIC_positive.to_numpy().flatten()
    hforce_uDIC_positive = df[hforce_name].loc[df_displacements>=0]
    hforce_uDIC_positive = hforce_uDIC_positive.to_numpy().flatten()
    
    uDIC_negative = df_displacements.loc[df_displacements<=0]
    hforce_uDIC_negative = df[hforce_name].loc[df_displacements<=0]
    uDIC_negative = uDIC_negative.to_numpy().flatten()
    hforce_uDIC_negative = hforce_uDIC_negative.to_numpy().flatten()
    
    #%% Construct the envelopes
    x_positive_env, y_positive_env = compute_envelope(uDIC_positive,hforce_uDIC_positive)
    x_negative_env, y_negative_env = compute_envelope(-uDIC_negative,-hforce_uDIC_negative)
    x_negative_env = -x_negative_env
    y_negative_env = -y_negative_env
    
  #%% SAVE envelopes to csv

    df_north_env = pd.DataFrame({'Displacement_Positive_[mm]':x_positive_env,
                                'Force_Positive_[MPa]':y_positive_env})
    df_south_env = pd.DataFrame({'Displacement_Negative_[mm]':x_negative_env,
                                 'Force_Negative_[MPa]':y_negative_env})
    output_envelop_positive = envelope_output_name + '_Positive.csv'
    output_envelop_negative = envelope_output_name + '_Negative.csv'
    df_north_env.to_csv(output_envelop_positive,mode='w', index=False)
    df_south_env.to_csv(output_envelop_negative,mode='w', index=False)
  
    #%% PRINT Maximum - Minimum Force
    maxF = df[hforce_name].max()
    minF = df[hforce_name].min()
    print('Max Force = ', maxF, 'kN')
    print('Min Force = ', minF, 'kN')
    print(' ')
    
    #%% BILINEAR CURVE
    
    Vp_negative = -528.324    # peak force [kN] 
    Vp_negative_70 = 0.7*Vp_negative  # peak force [kN]
    u_Vp_negative_70 = -1.07783665  # [mm]
    Vp_positive = 556.4155    # peak force [kN]
    Vp_positive_70 = 0.7*Vp_positive   # peak force [kN]
    u_Vp_positive_70 = 1.192175017   # [mm]
    stiff_neg = Vp_negative_70/u_Vp_negative_70 #[kN/mm]
    stiff_pos = Vp_positive_70/u_Vp_positive_70 #[kN/mm]
    Vu_negative = -500.61    # maksimalna sila [kN]
    Vu_positive = 533.96    # maksimalna sila [kN]
    ultimate_displacement_negative = -7.854623317  # ultimate displacement [mm]
    ultimate_displacement_positive = 5.614676683  # ultimate displacement [mm]
    

    # Pretvaranje displacement u drift
    def displacement_to_drift(displacement):
        return (displacement / wall_height)*100

    # Točke za bilinearnu krivulju (s nagibom do ultimate sile)
    x_values_negative = [
        0,  # (0, 0)
        displacement_to_drift(u_Vp_negative_70),  # (0.70 * Vp_negative, 0.70 * Vp_positive)
        displacement_to_drift(u_Vp_negative_70 + (Vu_negative - Vp_negative_70) / stiff_neg),  # Nagib prema stiffnessu do Vu_negative
        displacement_to_drift(ultimate_displacement_negative),  # Ultimate displacement negative
        ]

    y_values_negative = [
        0,  # (0, 0)
        Vp_negative_70,  # (0.70 * Vp_negative, 0.70 * Vp_positive)
        Vu_negative,  # Do Vu_negative
        Vu_negative,  # Ultimate displacement negative (horizontal)
        ]

    #   Definicija točaka za pozitivni smjer
    x_values_positive = [
        0,  # (0, 0)
        displacement_to_drift(u_Vp_positive_70),  # (0.70 * Vp_positive, 0.70 * Vp_negative)
        displacement_to_drift(u_Vp_positive_70 + (Vu_positive - Vp_positive_70) / stiff_pos),  # Nagib prema stiffnessu do Vu_positive
        displacement_to_drift(ultimate_displacement_positive),  # Ultimate displacement positive
        ]

    y_values_positive = [
        0,  # (0, 0)
        Vp_positive_70,  # (0.70 * Vp_positive, 0.70 * Vp_negative)
        Vu_positive,  # Do Vu_positive
        Vu_positive,  # Ultimate displacement positive (horizontal)
        ]
    #%% Find drifts
    
    # Drift at peak force:
    idx_peak_positive = y_positive_env.argmax()
    dr_peak_positive = x_positive_env[idx_peak_positive]/wall_height*100
    hforce_peak_positive = y_positive_env[idx_peak_positive]
    print('Drift at peak - positive: ', "%0.2f" % dr_peak_positive, ' - FORCE [kN]: ', hforce_peak_positive)
    
    idx_peak_negative = y_negative_env.argmin()
    dr_peak_negative = x_negative_env[idx_peak_negative]/wall_height*100
    hforce_peak_negative = y_negative_env[idx_peak_negative]
    print('Drift at peak - negative: ',"%0.2f" % dr_peak_negative, ' - FORCE [kN]: ', hforce_peak_negative)
    print(' ')

    # Drift at 20% drop positive:
    dr_u20_positive, hforce_u20_positive = compute_drift(x_positive_env, y_positive_env, 
                                                         0.8, idx_peak_positive, wall_height)
  
    # Drift at 20% drop negative:
    dr_u20_negative, hforce_u20_negative = compute_drift(x_negative_env, y_negative_env, 
                                                         0.8, idx_peak_negative, wall_height)    
    print(' ')
    # Drift at 50% drop positive:
    dr_u50_positive, hforce_u50_positive = compute_drift(x_positive_env, y_positive_env, 
                                                         0.5, idx_peak_positive, wall_height)
  
    # Drift at 20% drop negative:
    dr_u50_negative, hforce_u50_negative = compute_drift(x_negative_env, y_negative_env, 
                                                         0.5, idx_peak_negative, wall_height)     
    print(' ')   
    # Drift at collapse:
    dr_uc_positive = max(x_positive_env)/wall_height*100
    hforce_uc_positive = y_positive_env[x_positive_env.argmax()]
    print('Drift at collapse - positive: ', "%0.2f" % dr_uc_positive, ' - FORCE [kN]: ', hforce_uc_positive)
    
    dr_uc_negative = min(x_negative_env)/wall_height*100
    hforce_uc_negative = y_negative_env[x_negative_env.argmin()]
    print('Drift at collapse - negative: ', "%0.2f" % dr_uc_negative, ' - FORCE [kN]: ', hforce_uc_negative)
    print(' ')
    
    #%% Print Drifts to csv

    data_drifts =[['Direction','Drift_peak_[%]', 'Drift_20%_[%]','Drift_50%_[%]','Max_drift_[%]',
                   'Force_peak_[kN]','Force_20%_drop_[kN]','Force_50%_[kN]', 'Min_Force_[kN]'],
                               ['positive',dr_peak_positive,dr_u20_positive,dr_u50_positive,dr_uc_positive,
                                hforce_peak_positive,hforce_u20_positive,hforce_u50_positive,hforce_uc_positive],
                               ['negative',dr_peak_negative,dr_u20_negative,dr_u50_negative,dr_uc_negative,
                                hforce_peak_negative,hforce_u20_negative,hforce_u50_negative,hforce_uc_negative]]
    
    if j == 0:
        output_drifts = output_drifts_Plaster
#        with open(output_drifts_Plaster, 'w') as f:
#            f.write('Plaster side')
#            print('Plaster side')
#    else:
#        output_drifts = output_drifts_stone
#        with open(output_drifts_stone, 'a') as f:
#            f.write('Stone side')
#            print('Stone side')
#    f.close()
    
    df_drifts = pd.DataFrame(data_drifts)
    
    df_drifts.to_csv(output_drifts,mode='w',header=0, index=False)
    
    drifts_list = np.array([[dr_peak_positive,hforce_peak_positive],
                            [dr_u20_positive,hforce_u20_positive],
                            [dr_u50_positive,hforce_u50_positive],
                            [dr_uc_positive,hforce_uc_positive],
                            [dr_peak_negative,hforce_peak_negative],
                            [dr_u20_negative,hforce_u20_negative],
                            [dr_u50_negative,hforce_u50_negative],
                            [dr_uc_negative,hforce_uc_negative]])
#%% Drifts to plot

    drift =df_displacements
    drift = drift/wall_height*100

    #%% PLOT only Envelopes Stress- Drift
    fig_num +=1
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    ax1.plot(x_positive_env/wall_height*100,y_positive_env/area*1000,'b',label = 'Positive')
    ax1.plot(-x_negative_env/wall_height*100,-y_negative_env/area*1000,'r--', label='Negative')
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Shear Stress [$N/mm^2$]')
    ax1.set_title(plot_title)
#    ax1.set_ylim(stress_lim)
    ax1.set_xlim([0,1])
    ax1.grid()
    ax1.legend()
    plt.savefig('Envelopes.pdf', format='pdf')
    
    #%% PLOT only Envelopes Force- Drift
    fig_num +=1
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    ax1.plot(x_positive_env/wall_height*100,y_positive_env,'r+',label = 'Positive')
    ax1.plot(-x_negative_env/wall_height*100,-y_negative_env,'b+', label='Negative')
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Force [$kN$]')
    ax1.set_title(plot_title)
    ax1.set_ylim(force_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.legend()
    plt.savefig('Envelopes.pdf', format='pdf')
    #%% PLOT Envelopes with Stress-Drift
    
    fig_num +=1
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    ax1.plot(x_positive_env/wall_height*100,y_positive_env/area*1000,'r')
    ax1.plot(x_negative_env/wall_height*100,y_negative_env/area*1000,'r')
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Shear Stress [$N/mm^2$]')
    ax1.set_title(plot_title)
    ax1.set_ylim(stress_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.plot(drift,hforce/area*1000,'k',linewidth=0.75)
    
    
    #%% PLOT Envelopes with Force-Drift
    
    fig_num +=1
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    ax1.plot(x_positive_env/wall_height*100,y_positive_env,'r')
    ax1.plot(x_negative_env/wall_height*100,y_negative_env,'r')
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Force [$kN$]')
    ax1.set_title(plot_title)
    ax1.set_ylim(force_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.plot(drift,hforce,'k',linewidth=0.75)

    #%% PLOT Envelopes with Force-Drift - For the paper!
    
    # Initialize plot
    fig, ax1 = plt.subplots(figsize=(4, 4))  # Adjust figure size if needed

    # Plot envelopes (blue, on top of hysteresis curve)
    ax1.plot([x / wall_height * 100 for x in x_positive_env], y_positive_env, 'b', linewidth=1.2, zorder=3)
    ax1.plot([x / wall_height * 100 for x in x_negative_env], y_negative_env, 'b', linewidth=1.2, zorder=3)

    # Plot hysteresis curve (thin grey)
    ax1.plot(drift, hforce, color='grey', linewidth=0.3, zorder=2)

    # Set labels and limits
    ax1.set_xlabel('Drift [%]', fontsize=12, labelpad=12)
    ax1.set_ylabel('Force [kN]', fontsize=12)
#    ax1.set_title(plot_title)
    ax1.set_ylim(force_lim)
    ax1.set_xlim(drifts_lim)

    # Update gridlines
    ax1.grid(color='lightgrey', linestyle='--', linewidth=0.5, zorder=1)
    
    data[0] = data[0].astype(str)

    # Find the row where LS46 is located
    ls46_row = data[data[0].str.contains('LS46', na=False)]

    # If LS46 is found, extract the portion of the curve after it
    if not ls46_row.empty:
        ls46_index = ls46_row.index[0]
    
    # Get the drift and force values after LS46 (adjust column indices as needed)
    highlight_drift = drift[ls46_index:]  # Assuming 'drift' corresponds to the x-values
    highlight_force = hforce[ls46_index:]  # Assuming 'hforce' corresponds to the y-values
    
    # Highlight the part after LS46 in red
    ax1.plot(highlight_drift, highlight_force, color='red', linewidth=1.5, zorder=3, label='After LS46')
    
    # Bilinear curve plot (negative part)
    plt.plot(x_values_negative, y_values_negative, color='g', zorder=4)

   # Bilinear curve plot (positive part)
    plt.plot(x_values_positive, y_values_positive, color='g', zorder=4)
    
    # Add displacement as the top x-axis
    displacement = np.array(ax1.get_xticks()) * wall_height / 100
    ax2 = ax1.twiny()
    ax2.set_xlim(ax1.get_xlim())
    ax2.set_xticks(ax1.get_xticks())
    ax2.set_xticklabels([f"{d:.1f}" for d in displacement])
    ax2.set_xlabel("Displacement [mm]", fontsize=12, labelpad=12)

    # Move tick marks inside the graph and adjust thickness
    ax1.tick_params(
        axis='both',       # Apply to both axes
        direction='in',    # Ticks pointing inside
        length=3,          # Length of ticks
        width=1.0,         # Thickness of ticks
        colors='black',    # Tick color
        zorder=10          # Ensure ticks are above the gridlines
        )
    ax2.tick_params(
        axis='x',
        direction='in',
        length=3,
        width=1.0,
        colors='black',
        zorder=10
        )
    # Add secondary y-axis on the opposite side (right side) for force
    ax3 = ax1.twinx()
    ax3.set_ylim(force_lim)
    ax3.set_yticklabels([])  # Remove the y-axis labels (force values)
    ax3.tick_params(
        axis='y',
        direction='in',
        length=3,
        width=1.0,
        colors='black',
        zorder=10
        )
 
    # Add legend with custom text
    
    custom_legend_text = (
        r"$SCW\_A$" "\n"
        r"$\sigma_{v,\mathrm{top}}/f_c = 20\%$" "\n"
        r"$H_0/H = 0.5$"
        )
    
    # Create a dummy line for the legend handle (invisible)
    dummy_line = plt.Line2D([0], [0], color='none', linewidth=0)
   
    # Adding the legend with custom text and no line markers
    plt.legend(
            handles=[dummy_line],
            labels=[custom_legend_text], 
            loc='upper left', 
            bbox_to_anchor=(-0.1, 1),  # This anchors the legend exactly to the upper left corner
            frameon=False,  # Removes all lines/markers from the legend
            labelspacing=2.0,  # Vertical space between legend entries
            fontsize = 10)

    # Save the plot to PDF with adjusted margins
    figure_folder_path = '../03_figures'
    figure_filename = 'SCW_A_force_displacement_plot.png'
    
    data_path = os.path.join(data_folder_path, data_file)
    figure_path = os.path.join(figure_folder_path, figure_filename)
    
    # Create the figure folder if it doesn't exist
    os.makedirs(figure_folder_path, exist_ok=True)
    
    # Save figure
    plt.savefig(figure_path, format='png', bbox_inches='tight', dpi=300)
    print(f"Figure saved at: {figure_path}")
    #plt.savefig(output_file, format='png', bbox_inches='tight', dpi = 300)

    # Show the plot
    plt.tight_layout()
    plt.show()

    
    #%% PLOT Envelopes with Force-Drift and selected drifts 
    
    
    fig_num +=1
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    ax1.plot(x_positive_env/wall_height*100,y_positive_env,'r')
    ax1.plot(x_negative_env/wall_height*100,y_negative_env,'r')
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Force [$kN$]')
    ax1.set_title(plot_title)
    ax1.set_ylim(force_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.plot(drift,hforce,'k',linewidth=0.75)
    ax1.plot(drifts_list[:,0],drifts_list[:,1],'o')
    #ax1.plot(drifts_list,'o')


    ax1.plot(drifts_lim,[0.8*maxF,0.8*maxF],'r--',linewidth=0.5)
    ax1.text(1.,0.85*maxF,'80 %  max F',color = 'r')
    ax1.plot(drifts_lim,[0.5*maxF,0.5*maxF],'b--',linewidth=0.5)
    ax1.text(1.,0.55*maxF,'50 % max F',color = 'b')

    ax1.plot(drifts_lim,[0.8*minF,0.8*minF],'r--',linewidth=0.5)
    ax1.text(1.,0.75*minF,'80 % min F',color = 'r')
    ax1.plot(drifts_lim,[0.5*minF,0.5*minF],'b--',linewidth=0.5)
    ax1.text(1.,0.45*minF,'50 % min F',color = 'b')    
    #%% Envelopes with Force-Drift and limits
    # DRIFT 
    # Plot Force vs Drift
    fig_num +=1 
    
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    
    ax1.plot(drift,hforce,'k',linewidth=0.75)
    ax1.plot(drifts_lim,[0.8*maxF,0.8*maxF],'r--',linewidth=0.5)
    ax1.text(1.,0.85*maxF,'80 %  max F',color = 'r')
    ax1.plot(drifts_lim,[0.5*maxF,0.5*maxF],'b--',linewidth=0.5)
    ax1.text(1.,0.55*maxF,'50 % max F',color = 'b')
    
    ax1.plot(drifts_lim,[0.8*minF,0.8*minF],'r--',linewidth=0.5)
    ax1.text(1.,0.75*minF,'80 % min F',color = 'r')
    ax1.plot(drifts_lim,[0.5*minF,0.5*minF],'b--',linewidth=0.5)
    ax1.text(1.,0.45*minF,'50 % min F',color = 'b')
    
    xticks =np.arange(-2,2,0.5)
    ax1.set_xticks(xticks)
    ax1.set_ylim(force_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Force [kN]')
    
    
    if save_image == True:
        image_name_pdf = str(image_name) + 'Force_Drift.pdf'
        plt.savefig(image_name_pdf)
    
    #%% Envelopes with Stress-Drift and limits
    # DRIFT 
    # Plot Force vs Drift
    fig_num +=1 
    
    fig = plt.figure(fig_num)
    ax1 = fig.add_subplot(1,1,1)
    
    maxS = df[hforce_name].max()/area*1000
    minS = df[hforce_name].min()/area*1000
    
    ax1.plot(drift,hforce/area*1000,'k',linewidth=0.75)
    ax1.plot(drifts_lim,[0.8*maxS,0.8*maxS],'r--',linewidth=0.5)
    ax1.text(1.,0.85*maxS,'80 %  max τ',color = 'r')
    ax1.plot(drifts_lim,[0.5*maxS,0.5*maxS],'b--',linewidth=0.5)
    ax1.text(1.,0.55*maxS,'50 %max τ',color = 'b')
    
    ax1.plot(drifts_lim,[0.8*minS,0.8*minS],'r--',linewidth=0.5)
    ax1.text(1.,0.75*minS,'80 % min τ',color = 'r')
    ax1.plot(drifts_lim,[0.5*minS,0.5*minS],'b--',linewidth=0.5)
    ax1.text(1.,0.45*minS,'50 % min τ',color = 'b')
    
    
    xticks =np.arange(-3,3,0.5)
    ax1.set_xticks(xticks)
    ax1.set_ylim(stress_lim)
    ax1.set_xlim(drifts_lim)
    ax1.grid()
    ax1.set_xlabel('Drift [%]')
    ax1.set_ylabel('Shear Stress τ [$N/mm^2$]')
    
    if save_image == True:
        image_name_pdf = str(image_name) + 'Stress_Drift.pdf'
        plt.savefig(image_name_pdf)

#%% # Plot LVDT vs DIC
fig_num +=1

fig = plt.figure(fig_num)
ax1 = fig.add_subplot(1,1,1)
#ax1.plot(uDIC_Stone/wall_height*100,hforce, label='DIC Stone side')
ax1.plot(uDIC_Plaster/wall_height*100,hforce, label='DIC Plaster side')
ax1.plot(uLVDT/wall_height*100,hforce, label='LVDT bottom')
ax1.set_title(title)
ax1.legend()
ax1.grid()
ax1.set_xlabel('Drift [%]')
ax1.set_ylabel('Force [kN]')


if save_image == True:
     image_name_pdf = str(image_name) + 'DIC_LVDT.pdf'
     plt.savefig(image_name_pdf)
     image_name = str(image_name) + '.png'
     plt.savefig(image_name)


#%% DIC Stone-Plaster sides over time


fig_num +=1
fig = plt.figure(fig_num)
ax1 = fig.add_subplot(1,1,1)
x = np.linspace(0,len(uDIC_Plaster),len(uDIC_Plaster))
ax1.plot(x,uDIC_Plaster,'r', label='DIC Plaster side',linewidth=0.5)
#ax1.plot(x,uDIC_Stone, 'b--', label='DIC Stone side',linewidth=0.5)
ax1.set_xlabel('Step')
ax1.set_ylabel('Displacement [mm]')
ax1.set_title(title)
ax1.grid()
ax1.legend()

if save_image == True:
     image_name_pdf = str(image_name) + 'Plaster_vs_Stone_side.pdf'
     plt.savefig(image_name_pdf)


#%% Specific plot

#substring = 'LS53_to_LS54'
#x = df[uLVDT_name][df['Image_name'].str.contains(substring)]
#x2 = df[uDIC_Plaster_column][df['Image_name'].str.contains(substring)]
#y = df[hforce_name][df['Image_name'].str.contains(substring)]


#fig_num +=1
#fig = plt.figure(fig_num)
#ax1 = fig.add_subplot(1,1,1)
#ax1.plot(x,y,'-+', label='LVDT',linewidth=0.5)
#ax1.plot(x2,y, '-o', label='DIC Plaster side',linewidth=0.5)
##ax1.set_xlabel('Step')
##ax1.set_ylabel('Displacement [mm]')
#ax1.grid()
#ax1.legend()